pub fn ast_to_string(expr: &SpannedExpr) -> StringExpand description
Convert a CEL AST to source text.
The output is a valid CEL expression that is semantically equivalent to the input AST. Formatting may differ from the original source.
pub fn ast_to_string(expr: &SpannedExpr) -> StringConvert a CEL AST to source text.
The output is a valid CEL expression that is semantically equivalent to the input AST. Formatting may differ from the original source.