MacroStyle

Enum MacroStyle 

pub enum MacroStyle {
    Global,
    Receiver,
}
Indicates whether a macro is called as a global function or as a method on a receiver.

Variants



Global

Global function call: macro_name(args...)



Receiver

Receiver-style method call: receiver.macro_name(args...)