pub struct EnumValue {
pub type_name: Arc<str>,
pub value: i32,
}Expand description
A CEL enum value with type information.
Used for strong enum typing where enum values carry their fully qualified type name alongside the numeric value.
Fields
type_name: Arc<str>The fully qualified enum type name (e.g., “cel.expr.conformance.proto3.GlobalEnum”).
value: i32The numeric enum value.
Implementations